/* Blinker
   Copyright 2011 Stefan Schuermans <stefan@blinkenarea.org>
   Copyleft GNU public license - http://www.gnu.org/copyleft/gpl.html
   a blinkenarea.org project */

#ifndef BLINKER_MODULE_H
#define BLINKER_MODULE_H

#include "CallMgr.h"
#include "Directory.h"
#include "StreamMgr.h"

namespace Blinker {

/// base class for modules
class Module
{
public:
  /**
   * @brief constructor
   * @param[in] callMgr callback manager
   * @param[in] streamMgr stream manager
   * @param[in] dirBase base directory
   */
  Module(CallMgr &callMgr, StreamMgr &streamMgr, const Directory &dirBase);

  /// virtual destructor
  virtual ~Module();

private:
  /// copy constructor disabled
  Module(const Module &that);

  /// assignment operator disabled
  const Module & operator=(const Module &that);

public:
  /// check for update of configuration
  virtual void updateConfig() = 0;

protected:
  CallMgr   &m_callMgr;   ///< callback manager
  StreamMgr &m_streamMgr; ///< stream manager
  Directory m_dirBase;    ///< base directory
}; // class Module

} // namespace Blinker

#endif // #ifndef BLINKER_MODULE_H

