/* Blinker
   Copyright 2011 Stefan Schuermans <stefan@blinkenarea.org>
   Copyleft GNU public license - http://www.gnu.org/copyleft/gpl.html
   a blinkenarea.org project */

#ifndef BLINKER_MODULEMGR_H
#define BLINKER_MODULEMGR_H

#include <list>

#include "CallMgr.h"
#include "Directory.h"
#include "ListTracker.h"
#include "Module.h"
#include "StreamMgr.h"
#include "TimeCallee.h"

namespace Blinker {

/// manager for modules of one type
template<typename MODULE>
class ModuleMgr: public TimeCallee
{
protected:
  /// module container
  class Cntr;

  /// module list tracker
  typedef ListTracker<ModuleMgr, Cntr, Directory> ModuleListTracker;

public:
  /**
   * @brief constructor
   * @param[in] callMgr callback manager
   * @param[in] streamMgr stream manager
   * @param[in] dirBase base directory
   */
  ModuleMgr(CallMgr &callMgr, StreamMgr &streamMgr, const Directory &dirBase);

  /// destructor
  ~ModuleMgr();

private:
  /// copy constructor disabled
  ModuleMgr(const ModuleMgr &that);

  /// assignment operator disabled
  const ModuleMgr & operator=(const ModuleMgr &that);

public:
  /// callback when requested time reached
  virtual void timeCall();

protected:
  /// check for update of configuration
  void updateConfig();

protected:
  CallMgr           &m_callMgr;          ///< callback manager
  StreamMgr         &m_streamMgr;        ///< stream manager
  Directory         m_dirBase;           ///< base directory
  ModuleListTracker m_moduleListTracker; ///< module list tracker
}; // class ModuleMgr

} // namespace Blinker

#endif // #ifndef BLINKER_MODULEMGR_H

