/* Blinker
   Copyright 2011 Stefan Schuermans <stefan@blinkenarea.org>
   Copyleft GNU public license - http://www.gnu.org/copyleft/gpl.html
   a blinkenarea.org project */

#ifndef BLINKER_PLAYER_H
#define BLINKER_PLAYER_H

#include <list>
#include <string>

#include <BlinkenLib/BlinkenMovie.h>

#include "CallMgr.h"
#include "Directory.h"
#include "File.h"
#include "Module.h"
#include "ListTracker.h"
#include "OutStreamFile.h"
#include "StreamMgr.h"
#include "Time.h"
#include "TimeCallee.h"

namespace Blinker {

/// a movie player
class Player: public Module, public TimeCallee
{
protected:
  /// movie in playlist
  class Movie;

  /// playlist tracker
  typedef ListTracker<Player, Movie, File> PlaylistTracker;

  /// playlist iterator
  typedef PlaylistTracker::ListIt PlaylistIt;

public:
  /**
   * @brief constructor
   * @param[in] callMgr callback manager
   * @param[in] streamMgr stream manager
   * @param[in] dirBase base directory
   */
  Player(CallMgr &callMgr, StreamMgr &streamMgr, const Directory &dirBase);

  /// virtual destructor
  virtual ~Player();

private:
  /// copy constructor disabled
  Player(const Player &that);

  /// assignment operator disabled
  const Player & operator=(const Player &that);

public:
  /// check for update of configuration
  virtual void updateConfig();

  /// callback when requested time reached
  virtual void timeCall();

protected:
  /// check if current movie changed and react
  void checkCurChanged();

  /// process current frame
  void procFrame();

  /// send current frame to output stream
  void sendFrame();

protected:
  OutStreamFile   m_fileOutStream;   ///< output stream name file
  PlaylistTracker m_playlistTracker; ///< current playlist
  bool            m_curValid;        ///< if there is a current frame
  PlaylistIt      m_curEntry;        ///< current playlist entry
  int             m_curFrame;        ///< current frame in movie
  bool            m_curChange;       ///< current movie changed
  Time            m_nextTime;        ///< when to show next frame
}; // class Player

} // namespace Blinker

#endif // #ifndef BLINKER_PLAYER_H

