/* Blinker
   Copyright 2011 Stefan Schuermans <stefan@blinkenarea.org>
   Copyleft GNU public license - http://www.gnu.org/copyleft/gpl.html
   a blinkenarea.org project */

#ifndef BLINKER_PRINTER_H
#define BLINKER_PRINTER_H

#include <string>

#include <BlinkenLib/BlinkenFrame.h>

#include "CallMgr.h"
#include "Directory.h"
#include "File.h"
#include "InStreamFile.h"
#include "Module.h"
#include "StreamMgr.h"
#include "StreamRecv.h"

namespace Blinker {

/// a stream printer
class Printer: public Module, public StreamRecv
{
public:
  /**
   * @brief constructor
   * @param[in] callMgr callback manager
   * @param[in] streamMgr stream manager
   * @param[in] dirBase base directory
   */
  Printer(CallMgr &callMgr, StreamMgr &streamMgr, const Directory &dirBase);

  /// virtual destructor
  virtual ~Printer();

private:
  /// copy constructor disabled
  Printer(const Printer &that);

  /// assignment operator disabled
  const Printer & operator=(const Printer &that);

public:
  /// check for update of configuration
  virtual void updateConfig();

  /**
   * @brief set current frame
   * @param[in] stream stream name
   * @param[in] pFrame current frame (NULL for none)
   */
  virtual void setFrame(const std::string &stream, stBlinkenFrame *pFrame);

protected:
  InStreamFile m_fileInStream; ///< input stream name file
}; // class Printer

} // namespace Blinker

#endif // #ifndef BLINKER_PRINTER_H

