/* Blinker
   Copyright 2011 Stefan Schuermans <stefan@blinkenarea.org>
   Copyleft GNU public license - http://www.gnu.org/copyleft/gpl.html
   a blinkenarea.org project */

#include <iostream>
#include <string>

#include "CallMgr.h"
#include "Canvas.h"
#include "Directory.h"
#include "FlexiPix.h"
#include "ModuleMgr.h"
#include "ModuleMgr_impl.h"
#include "Output.h"
#include "Player.h"
#include "Printer.h"
#include "Priority.h"
#include "Resizer.h"
#include "Scaler.h"
#include "StreamMgr.h"
#include "Udp4Sender.h"

using namespace Blinker;

void run(const std::string &dirConfig)
{
  Directory dirCfg(dirConfig);

  CallMgr callMgr;
  StreamMgr streamMgr;

  ModuleMgr<Canvas> canvasMgr(callMgr, streamMgr,
                              dirCfg.getSubdir("canvases"));
  ModuleMgr<FlexiPix> flexipixMgr(callMgr, streamMgr,
                                  dirCfg.getSubdir("flexipixes"));
  ModuleMgr<Output> outputMgr(callMgr, streamMgr,
                              dirCfg.getSubdir("outputs"));
  ModuleMgr<Player> playerMgr(callMgr, streamMgr,
                              dirCfg.getSubdir("players"));
  ModuleMgr<Printer> printerMgr(callMgr, streamMgr,
                                dirCfg.getSubdir("printers"));
  ModuleMgr<Priority> priorityMgr(callMgr, streamMgr,
                                  dirCfg.getSubdir("priorities"));
  ModuleMgr<Resizer> resizerMgr(callMgr, streamMgr,
                                dirCfg.getSubdir("resizers"));
  ModuleMgr<Scaler> scalersMgr(callMgr, streamMgr,
                               dirCfg.getSubdir("scalers"));
  ModuleMgr<Udp4Sender> udp4Mgr(callMgr, streamMgr,
                                dirCfg.getSubdir("udp4senders"));

  callMgr.run();
}

int main(int argc, const char *argv[])
{
  const char * dirConfig;

  if (argc < 2) {
    std::cerr << "Blinker" << std::endl
              << "configuration:"BLINKER_CONFIG << std::endl
              << "usage: " << argv[0] << " config-directory" << std::endl;
    return 2;
  }
  dirConfig = argv[1];

  run(dirConfig);

  return 0;
}

